'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _styles = require('./styles');

var _styles2 = _interopRequireDefault(_styles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * Sets padding and width and works independently or as a child of <Flex />.
 */

var Box = function Box(_ref) {
  var p = _ref.p;
  var px = _ref.px;
  var py = _ref.py;
  var pt = _ref.pt;
  var pb = _ref.pb;
  var pl = _ref.pl;
  var pr = _ref.pr;
  var flex = _ref.flex;
  var auto = _ref.auto;
  var col = _ref.col;
  var style = _ref.style;
  var className = _ref.className;

  var props = _objectWithoutProperties(_ref, ['p', 'px', 'py', 'pt', 'pb', 'pl', 'pr', 'flex', 'auto', 'col', 'style', 'className']);

  var breakpoints = _styles2.default.breakpoints;
  var scale = _styles2.default.scale;


  function w(n) {
    return n ? n / 12 * 100 + '%' : null;
  }

  var width = w(col);

  if (typeof window !== 'undefined') {
    Object.keys(breakpoints).forEach(function (key) {
      if (props[key] && window.matchMedia(breakpoints[key]).matches) {
        width = w(props[key]) || width;
      }
    });
  }

  var sx = Object.assign({}, style, {
    boxSizing: 'border-box',
    flex: auto ? '1 1 auto' : null,
    display: flex ? 'flex' : null,
    padding: p ? scale[p] : null,
    paddingTop: py ? scale[py] : pt ? scale[pt] : null,
    paddingBottom: py ? scale[py] : pb ? scale[pb] : null,
    paddingLeft: px ? scale[px] : pl ? scale[pl] : null,
    paddingRight: px ? scale[px] : pr ? scale[pr] : null,
    width: width,
    flexBasis: width
  });

  var cx = className ? 'Box ' + className : 'Box';

  return _react2.default.createElement('div', _extends({}, props, {
    style: sx,
    className: cx }));
};

var scaleIndexes = Array.from({ length: _styles2.default.scale.length }, function (s, i) {
  return i;
});

Box.propTypes = {
  /** Sets flex: 1 1 auto */
  auto: _react2.default.PropTypes.bool,
  /** Sets display: flex */
  flex: _react2.default.PropTypes.bool,
  /** Sets width and flex-basis based on a 12 column grid */
  col: _react2.default.PropTypes.oneOf([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]),
  /** Sets padding based on a scale of 0–4 */
  p: _react2.default.PropTypes.oneOf(scaleIndexes),
  /** Sets padding-left and padding-right based on a scale of 0–4 */
  px: _react2.default.PropTypes.oneOf(scaleIndexes),
  /** Sets padding-top and padding-bottom based on a scale of 0–4 */
  py: _react2.default.PropTypes.oneOf(scaleIndexes),
  /** Sets padding-top based on a scale of 0–4 */
  pt: _react2.default.PropTypes.oneOf(scaleIndexes),
  /** Sets padding-bottom based on a scale of 0–4 */
  pb: _react2.default.PropTypes.oneOf(scaleIndexes),
  /** Sets padding-left based on a scale of 0–4 */
  pl: _react2.default.PropTypes.oneOf(scaleIndexes),
  /** Sets padding-right based on a scale of 0–4 */
  pr: _react2.default.PropTypes.oneOf(scaleIndexes)
};

exports.default = Box;