'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _styles = require('./styles');

var _styles2 = _interopRequireDefault(_styles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * Creates a flexbox context to control layout of children.
 */

var Flex = function Flex(_ref) {
  var wrap = _ref.wrap;
  var column = _ref.column;
  var align = _ref.align;
  var justify = _ref.justify;
  var gutter = _ref.gutter;
  var auto = _ref.auto;
  var style = _ref.style;
  var className = _ref.className;

  var props = _objectWithoutProperties(_ref, ['wrap', 'column', 'align', 'justify', 'gutter', 'auto', 'style', 'className']);

  var display = 'flex';
  var breakpoints = _styles2.default.breakpoints;
  var scale = _styles2.default.scale;


  if (typeof window !== 'undefined') {
    Object.keys(breakpoints).forEach(function (key) {
      if (Object.keys(props).indexOf(key) > -1) {
        display = 'block';
      }
    });
    Object.keys(breakpoints).forEach(function (key) {
      if (props[key] && window.matchMedia(breakpoints[key]).matches) {
        display = 'flex';
      }
    });
  }

  var sx = Object.assign({}, style, {
    display: display,
    flexWrap: wrap ? 'wrap' : null,
    flexDirection: column ? 'column' : null,
    flex: auto ? '1 1 auto' : null,
    alignItems: align || null,
    justifyContent: justify || null,
    marginLeft: gutter ? -scale[gutter] : null,
    marginRight: gutter ? -scale[gutter] : null
  });

  var cx = className ? 'Flex ' + className : 'Flex';

  return _react2.default.createElement('div', _extends({}, props, {
    style: sx,
    className: cx }));
};

var scaleIndexes = Array.from({ length: _styles2.default.scale.length }, function (s, i) {
  return i;
});

Flex.propTypes = {
  /** Sets flex-wrap: wrap */
  wrap: _react2.default.PropTypes.bool,
  /** Sets flex-direction: column */
  column: _react2.default.PropTypes.bool,
  /** Sets negative left and right margins to compensate for <Box /> padding */
  gutter: _react2.default.PropTypes.oneOf(scaleIndexes),
  /** Sets align-item */
  align: _react2.default.PropTypes.oneOf(['stretch', 'center', 'baseline', 'flex-start', 'flex-end']),
  /** Sets justify-content */
  justify: _react2.default.PropTypes.oneOf(['center', 'space-around', 'space-between', 'flex-start', 'flex-end']),
  /** Sets flex: 1 1 auto */
  auto: _react2.default.PropTypes.bool
};

exports.default = Flex;